# card-py-bot

A magic card link auto card data parser and embedder.

### Installation and Use
To install card-py-bot using pip3 simply enter within your terminal:

```$ pip3 install card-py-bot```

After installing with pip3, entering the card-py-bot startup command within
terminal will spool up an instance of the card-py-bot. By default this command
is as follows:

```$ card-py-bot -t "path to file containing token string"```

### Requirements
**Python3.6:** This bot utilizes python3.6 to utilize webscraping on WOTC
MTG's main card website. Python3.6 (and pip) can be downloaded for multiple
OSes here:

```https://www.python.org/downloads/release/python-360/```

**Note:** Python3.6 should be installed within the C:\\Program Files directory.

### Disclaimer
All card data, card images, and intellectual property owned by Wizards of
the West Coast is rightfully owned by them. This is simply a fan made
creation to help instigate intense Commander Deck discussions.
